@@ -6,7 +6,7 @@ import requests
 
 class RatesNotAvailableError(Exception):
     """
-    Custome Exception when https://ratesapi.io is Down and not available for currency rates
+    Custome Exception when https://theforexapi.com is Down and not available for currency rates
     """
     pass
 
@@ -37,9 +37,8 @@ class Common:
             decoded_data = json.loads(response.text, use_decimal=True)
         else:
             decoded_data = response.json()
-        if (date_str and date_str != 'latest'
-                and date_str != decoded_data.get('date')):
-            raise RatesNotAvailableError("Currency Rates Source Not Ready")
+        # if (date_str and date_str != 'latest' and date_str != decoded_data.get('date')):
+        #     raise RatesNotAvailableError("Currency Rates Source Not Ready")
         return decoded_data.get('rates', {})
 
     def _get_decoded_rate(
